
try:
    from .version import __version__
except:
    pass

from .get_data import get_data
from .get_data import get_models
from .get_data import dewarp_imageset
from .get_data import super_res_mcimage
from .get_data import dipy_dti_recon
from .get_data import segment_timeseries_by_meanvalue
from .get_data import wmh
from .get_data import neuromelanin
from .get_data import joint_dti_recon
from .get_data import resting_state_fmri_networks
from .get_data import t1_based_dwi_brain_extraction
from .get_data import dwi_deterministic_tracking
from .get_data import dwi_closest_peak_tracking
from .get_data import dwi_streamline_connectivity
from .get_data import hierarchical_modality_summary
from .get_data import dwi_streamline_pairwise_connectivity
from .get_data import write_bvals_bvecs
from .get_data import mm
from .get_data import mm_nrg
from .get_data import write_mm
from .get_data import mask_snr
from .get_data import crop_mcimage
from .get_data import alff_image
from .get_data import alffmap
from .get_data import spec_taper
from .get_data import spec_ci
from .get_data import spec_pgram
from .get_data import plot_spec
from .get_data import down2iso
from .get_data import tra_initializer
from .get_data import mm_read
from .get_data import nrg_filelist_to_dataframe
from .get_data import bind_wide_mm_csvs




from setuptools import setup

long_description = open("README.md").read()

with open("./requirements.txt") as f:
      requirements = f.read().splitlines()

setup(name='antspymm',
      version='0.6.4',
      description='multi-channel/time-series medical image processing with antspyx',
      long_description=long_description,
      long_description_content_type="text/markdown; charset=UTF-8; variant=GFM",
      url='https://github.com/stnava/ANTsPyMM',
      author='Avants, Gosselin, Tustison, Reardon',
      author_email='stnava@gmail.com',
      license='Apache 2.0',
      install_requires=requirements,
      packages=['antspymm'],
      zip_safe=False)
